import React, { useEffect, useState } from "react"
import TableData from "../../components/TableData"
import columns12 from "./tableConfig"
import { GameDayProps, getGameDayListApi } from "@/services/gameData/game"
import { useAjax } from "@/Hook/useAjax"
import QueryForm from "@/components/QueryForm"
import moment from "moment"
import RechargeTrendGame from "@/components/rechargeTrend/index_game"

/**
 * 游戏每日数据
 * @returns 
 */
const Everyday: React.FC = () => {

    /*****************************/
    const [queryForm, setQueryForm] = useState<GameDayProps>({
        pageNum: 1, pageSize: 20,
        registeredBeginDate: moment().format('YYYY-MM-DD'),
        registeredEndDate: moment().format('YYYY-MM-DD'),
        sourceSystem: 'ZX_ONE'
    })

    const [rtConfig, setRtConfig] = useState<{ gameId?: number, gameName?: string, beginDate?: string, sourceSystem?: string, visible: boolean }>({ visible: false })

    const getGameDayList = useAjax((params) => getGameDayListApi(params))
    /*****************************/

    useEffect(() => {
        getGameDayList.run(queryForm)
    }, [queryForm])

    const rechargeTrendHandle = (data: any) => {
        setRtConfig({ visible: true, gameName: data?.gameName, gameId: data?.gameId, sourceSystem: data?.sourceSystem, beginDate: data.costDate })
    }

    return <div>
        <TableData
            leftChild={<QueryForm
                initialValues={{ regDay: [moment(), moment()], sourceSystem: 'ZX_ONE' }}
                onChange={(data: any) => {
                    console.log(data)
                    const { regStartDay, regEndDay, rechargeDay, ...params } = data
                    let newQueryForm = JSON.parse(JSON.stringify(queryForm))
                    newQueryForm.pageNum = 1
                    if (regStartDay && regEndDay) {
                        newQueryForm.registeredBeginDate = regStartDay
                        newQueryForm.registeredEndDate = regEndDay
                    } else {
                        delete newQueryForm.registeredBeginDate
                        delete newQueryForm.registeredEndDate
                    }
                    if (rechargeDay && rechargeDay?.length === 2) {
                        newQueryForm['rechargeBeginDate'] = moment(rechargeDay[0]).format('YYYY-MM-DD')
                        newQueryForm['rechargeEndDate'] = moment(rechargeDay[0]).format('YYYY-MM-DD')
                    } else {
                        delete newQueryForm['rechargeBeginDate']
                        delete newQueryForm['rechargeEndDate']
                    }
                    setQueryForm({ ...newQueryForm, ...params })
                }}
                isSource
                isRegDay
                isGameId
                isBGGameClassify
            />}
            scroll={{ x: 1000, y: 600 }}
            ajax={getGameDayList}
            fixed={{ left: 5, right: 1 }}
            dataSource={getGameDayList?.data?.records?.map((item: any, index: number) => ({ ...item, id: Number(queryForm.pageNum.toString() + index.toString()) }))}
            total={getGameDayList?.data?.total}
            page={queryForm.pageNum}
            pageSize={queryForm.pageSize}
            title='游戏每日数据'
            onChange={(props: any) => {
                let { pagination, sortData } = props
                let { current, pageSize } = pagination
                let newQueryForm = JSON.parse(JSON.stringify(queryForm))
                if (sortData && sortData?.order) {
                    newQueryForm['sortType'] = sortData?.order === 'ascend' ? 'asc' : 'desc'
                    newQueryForm['sortFiled'] = sortData?.field
                } else {
                    delete newQueryForm['sortType']
                    delete newQueryForm['sortFiled']
                }
                newQueryForm.pageNum = current
                newQueryForm.pageSize = pageSize
                setQueryForm({ ...newQueryForm })
            }}
            config={columns12(rechargeTrendHandle)}
            configName={'游戏每日数据'}
        />
        {rtConfig.visible && <RechargeTrendGame {...rtConfig} onClose={() => setRtConfig({ visible: false })} />}
    </div>
}

export default Everyday