import { request } from 'umi';
import { api } from '../api';
import { Paging, SortProps } from './rankingList';
let wapi = api + '/gameData'

export interface GameWaterProps extends Paging, SortProps {
    gameClassify?: string,
    gameName?: string,
    rechargeDate?: string
}
/**
 * 每日流水贡献
 * @param data 
 * @returns 
 */
export async function getGameWaterListApi(data: GameWaterProps) {
    return request(wapi + `/gameData/water`, {
        method: 'POST',
        data
    });
}

export interface GameTotalProps extends Paging, SortProps {
    gameClassify?: string,
    gameName?: string,
    // 充值开始时间
    rechargeBeginDate?: string
    rechargeEndDate?: string
    // 注册开始时间
    registeredBeginDate?: string
    registeredEndDate?: string
}
/**
 * 游戏总数据
 * @param data 
 * @returns 
 */
export async function getGameTotalListApi(data: GameTotalProps) {
    return request(wapi + `/gameData/total`, {
        method: 'POST',
        data
    });
}

export type GameDayProps = Omit<GameTotalProps, 'rechargeBeginDate' | 'rechargeEndDate'>
/**
 * 游戏每日数据
 * @param data 
 * @returns 
 */
export async function getGameDayListApi(data: GameDayProps) {
    return request(wapi + `/gameData/day`, {
        method: 'POST',
        data
    });
}

export interface GameH5Props extends Paging, SortProps {
    // 注册开始时间
    costBeginDate?: string,
    costEndDate?: string,
    gameName?: string,
    // 充值开始时间
    rechargeBeginDate?: string,
    rechargeEndDate?: string
}

export async function getGameH5ListApi(data: GameH5Props) {
    return request(wapi + `/gameData/h5`, {
        method: 'POST',
        data
    });
}


export interface GameAgainProps {
    gameId: number,
    gameName: string,
    beginDate?: string,
    endDate?: string,
    sourceSystem?: string
}
/**
 * 推广渠道每日复充数据q
 * @param data 
 * @returns 
 */
export async function getGameDataAgainListApi(data: GameAgainProps) {
    return request(wapi + `/gameData/again`, {
        method: 'POST',
        data
    });
}